@@ -10,6 +10,8 @@
 #include "gamma.h"
 #include "exp.h"
 #include "beta.h"
+#include "negbin.h"
+#include "skellam.h"
 #include "mvnorm.h"
 #include "mvt.h"
 
@@ -32,6 +34,8 @@ arma::vec Score_univ(double dY, arma::vec vTheta,std::string Dist){
   if(Dist == "gamma") vScore = gamma_Score(dY,vTheta);
   if(Dist == "exp")  vScore = exp_Score(dY,vTheta(0));
   if(Dist == "beta") vScore = beta_Score(dY,vTheta);
+  if(Dist == "negbin") vScore = negbin_Score(dY, vTheta);
+  if(Dist == "skellam") vScore = skellam_Score(dY, vTheta);
 
   return vScore;
 
