@@ -19,4 +19,7 @@ arma::vec Thresholding_vec(arma::vec vX, double dTol=1e50);
 double IndicatorLess(double dX, double dXBar);
 double signum(const double x);
 double Heaviside(const double x, const double a);
+double ModBesselFirst(double dX, double dNu, int iM = 1000);
+double ModBesselFirst_Deriv(double dX, double dNu, int iM = 1000);
+double LogSum(double dLogX, double dLogY) ;
 #endif
