@@ -150,7 +150,7 @@ double sstdexkurt( double dXi, double dNu )
   // Theoretical moments based on bijection betweeen Fernandez and Steel verions
   // and Hansen's Generalized Skew-T (credit due to Michael Rockinger)
   double m4 = 0.0;
-  if(dNu > 4 ){
+  if(dNu > 4.0){
     double eta  = dNu;
     double k2   = pow(dXi,2.0);
     double lda  = (k2-1.0)/(k2+1.0);
@@ -216,10 +216,14 @@ arma::vec sstd_Score(double dY, arma::vec vTheta){
   double dXi    = vTheta(2);
   double dNu    = vTheta(3);
 
-  double dMu1 = 2.0*pow(dNu - 2.0, 0.5)/(dNu - 1.0)  * Rf_gammafn(0.5*(dNu + 1.0))/(Rf_gammafn(0.5*dNu)*Rf_gammafn(0.5));
+  // double dMu1 = 2.0*pow(dNu - 2.0, 0.5)/(dNu - 1.0)  * Rf_gammafn(0.5*(dNu + 1.0))/(Rf_gammafn(0.5*dNu)*Rf_gammafn(0.5));
+
+  double dLogMu1 = log(2.0) + 0.5 * log(dNu - 2.0) - log(dNu - 1.0) + Rf_lgammafn(0.5 * (dNu + 1.0)) - Rf_lgammafn(0.5 * dNu) - Rf_lgammafn(0.5);
+  double dMu1    = exp(dLogMu1);
 
   double dMu_tilde = dMu1*(dXi - 1.0/dXi);
   double dSigma_tilde = pow( (1.0 - pow(dMu1, 2.0))*(pow(dXi, 2.0) + pow(dXi, -2.0)) + 2.0*pow(dMu1, 2.0) -1.0, 0.5);
+  double dLogSigma_tilde = 0.5 * log((1.0 - pow(dMu1, 2.0))*(pow(dXi, 2.0) + pow(dXi, -2.0)) + 2.0*pow(dMu1, 2.0) -1.0);
   double dZ = (dY - dMu)/dSigma * dSigma_tilde + dMu_tilde;
 
   double dXi_star  = dXi;
@@ -234,10 +238,7 @@ arma::vec sstd_Score(double dY, arma::vec vTheta){
     ddXi_star2 = -2.0/pow(dXi, 3.0);
   }
 
-  double dL = dZ;
-  double dC = 1.0 + pow(dL, 2.0)/(pow(dXi_star, 2.0) * (dNu - 2.0));
-  // double dG = 2.0/(dXi + 1.0/dXi);
-
+  double dC = 1.0 + pow(dZ, 2.0)/(pow(dXi_star, 2.0) * (dNu - 2.0));
 
   double dA = 0.5*Rf_gammafn(0.5*(dNu + 1.0)) * ( pow(dNu - 2.0, -0.5) + pow(dNu - 2.0, 0.5)*Rf_digamma(0.5*(dNu + 1.0)));
   double dB = Rf_gammafn(0.5 * dNu) + (dNu - 1.0)*Rf_digamma(0.5*dNu)*Rf_gammafn(0.5*dNu) * 0.5;
@@ -252,10 +253,36 @@ arma::vec sstd_Score(double dY, arma::vec vTheta){
 
   double ddMu    = (dNu + 1.0)/dC  * dSigma_tilde/dSigma * dZ/( pow(dXi_star, 2.0)*(dNu - 2.0) );
 
-  double ddSigma = -1.0/dSigma + (dNu + 1.0)/dC * dSigma_tilde/pow(dSigma, 2.0) * dZ*(dY - dMu)/( pow(dXi_star, 2.0)*(dNu - 2.0) );
+  // old one
+  // double ddSigma = -1.0/dSigma + (dNu + 1.0)/dC * dSigma_tilde/pow(dSigma, 2.0) * dZ*(dY - dMu)/( pow(dXi_star, 2.0)*(dNu - 2.0) );
+
+  double dQ = -1.0/dSigma;
+
+  double dFoo1_W = 2.0 * log(dXi_star) + log(dNu - 2.0);
+  double dFoo2_W = 2.0 * log(abs3(dZ));
+  double dW = -3.0 * log(dSigma) + 2.0 * dLogSigma_tilde + 2.0 * log(abs3(dY - dMu)) + log(dNu + 1.0) - LogSum(dFoo1_W, dFoo2_W);
+
+  double dFoo_E = dMu_tilde*(dY - dMu);
+
+  double dSgn = 0.0;
+
+  if (dFoo_E < 0) {
+
+    dSgn = -1.0;
+
+  } else {
+
+    dSgn = +1.0;
+
+  }
+
+  double dE = log(dNu + 1.0) + dLogSigma_tilde + log(abs3(dMu_tilde * (dY - dMu))) - 2.0 * log(dSigma) - LogSum(dFoo1_W, dFoo2_W);
+
+  double ddSigma = dQ + exp(dW) + dSgn * exp(dE);
+
 
   double ddNu     = ddSigma_tilde_nu/dSigma_tilde + 0.5*(1.0/dNu - 1.0/(dNu-2.0)) + Rf_digamma(0.5*(dNu+1.0))*0.5 -
-                    0.5*Rf_digamma(0.5*dNu) - 1.0/(2.0 * dNu) - 0.5*(log(dC) + dL*(dNu + 1.0)*(2.0*(dNu-2.0)*ddL_nu - dL)/(dC*pow(dXi_star*(dNu-2.0),2.0)));
+                    0.5*Rf_digamma(0.5*dNu) - 1.0/(2.0 * dNu) - 0.5*(log(dC) + dZ*(dNu + 1.0)*(2.0*(dNu-2.0)*ddL_nu - dZ)/(dC*pow(dXi_star*(dNu-2.0),2.0)));
 
 
   double ddLogSigma_tilde_xi = (1.0 + pow(dMu1, 2.0))*(dXi - pow(dXi, -3.0))/((1.0 + pow(dMu1, 2.0))*(pow(dXi, 2.0) + pow(dXi, -2.0)) + 2.0*pow(dMu1, 2.0) - 1.0 );
@@ -263,10 +290,10 @@ arma::vec sstd_Score(double dY, arma::vec vTheta){
 
   double ddLogG_xi = -(1.0 - 1.0/pow(dXi, 2.0))/(dXi + 1.0/dXi);
 
-  double dL1 = pow(dL, 2.0);
+  double dL1 = pow(dZ, 2.0);
   double dL2 = (dNu - 2.0) * pow(dXi_star, 2.0);
 
-  double ddL1 = 2.0 * dL * ( (dY - dMu)/dSigma *ddSigma_tilde_xi + dMu1*(1.0 + 1.0/pow(dXi, 2.0)) );
+  double ddL1 = 2.0 * dZ * ( (dY - dMu)/dSigma *ddSigma_tilde_xi + dMu1*(1.0 + 1.0/pow(dXi, 2.0)) );
   double ddL2 = (dNu - 2.0)*ddXi_star2;
 
   double ddXi    = ddLogG_xi + ddLogSigma_tilde_xi - 0.5 * (dNu + 1.0) *  1.0 / dC * ( ddL1*dL2 -  dL1* ddL2 )/pow(dL2, 2.0);
@@ -278,7 +305,6 @@ arma::vec sstd_Score(double dY, arma::vec vTheta){
   vScore(2) = ddXi;
   vScore(3) = ddNu;
 
-
   return vScore;
 
 }
